@@ -92,7 +92,8 @@ class Column(object):
         if self.primary_key and not issubclass(self.field_class, AutoField):
             params['primary_key'] = True
         if self.default is not None:
-            params['constraints'] = '[SQL(\'DEFAULT %s\')]' % self.default
+            params['constraints'] = '[SQL("DEFAULT %s")]' % \
+                    self.default.replace('"', '\\"')
 
         # Handle ForeignKeyField-specific attributes.
         if self.is_foreign_key():
@@ -583,7 +584,6 @@ class Introspector(object):
                 foreign_keys[table] = self.metadata.get_foreign_keys(
                     table, self.schema)
             except ValueError as exc:
-                err(*exc.args)
                 foreign_keys[table] = []
             else:
                 # If there is a possibility we could exclude a dependent table,
